#!/usr/bin/perl -I/usr/sausalito/perl
#
# this adds the guest user and group.
use Sauce::Config;
use CCE;
use Quota;

my $BlocksPerMB = 1024;

my $cce = new CCE;
$cce->connectuds();

my @oids = $cce->find('System');
if (not @oids) {
	$cce->bye('FAIL');
	exit 1;
}

my ($ok, $obj) = $cce->get($oids[0], 'FileShare'); 
if (not ($ok and $obj)) {
	$cce->bye('FAIL');
	exit 1;	
}

my $user = $obj->{guestUser};
my $group = $obj->{guestGroup};
my $wg = $obj->{guestWorkGroup};
if (not ($obj and $user and $wg and $group)) {
    $cce->bye('FAIL');
    exit 1;
}

my $err;

# try to create the group
if (not $cce->find('Workgroup', { "name" => $wg } )) {
    $ok = $cce->create('Workgroup', { name => $wg, enabled => 'true',
				      dont_delete => 'true',
				      description => '[[base-fileshare.guestDescription]]',
				      desc_readonly => 'true',
				      members => '&admin&' });
    if (!$ok) {
	$cce->bye('FAIL');
	exit 1;
    }
}

# okay, we now need to create the user
# NOTE: the guest user's group should not be the same as the workgroup.
my $dir = Sauce::Config::groupdir_base . '/' . $wg;
my $useradd = Sauce::Config::bin_useradd;
`$useradd -c 'guest share user' -d $dir -p '*' -s /bin/badsh -g $group $user` unless getpwnam($user);

# now, create/reset a public share. this should *not* be owned by 
# the guest user.
my $guestid = getpwnam($user);
my $uid = getpwnam(Sauce::Config::groupdir_owner());
my $gid = getgrnam($wg);
chown($uid, $gid, $dir);
chmod(02775, $dir);

# drop box
mkdir("$dir/incoming", 02773);
chmod(02773, "$dir/incoming"); # in case it already exists
chown($uid, $gid, "$dir/incoming");
mkdir("$dir/incoming/.AppleDouble", 02773);
chmod(02773, "$dir/incoming/.AppleDouble"); # in case it already exists
chown($uid, $gid, "$dir/incoming/.AppleDouble");

# currently, .AppleDesktop has to be writeable by others or else 
# guest copies of applications fail.
mkdir("$dir/.AppleDesktop", 02777);
chmod(02777, "$dir/.AppleDesktop"); 
chown($uid, $gid, "$dir/.AppleDesktop");

# create/touch a file to make quota stuff complain less.
open(FILE, ">$dir/.guest_settings");
close(FILE);
chown($guestid, $gid, "$dir/.guest_settings");
chmod(0000, "$dir/.guest_settings");

# now set the quota on the share
# this would work better if i could just force the handler to run.
my ($softquota, $hardquota, $softinode, $hardinode);
my $quota = $obj->{guestQuota}*$BlocksPerMB;
my $dev = Quota::getqcarg($dir);
Quota::sync($dev);
if ($quota eq 0) {
	$softquota = $hardquota = $softinode = $hardinode = 1;
} elsif ($quota gt 0) {
	$softquota = $quota;
	$hardquota = $softquota + $BlocksPerMB;
}
Quota::setqlim($dev, $guestid, $softquota, $hardquota, $softinode, $hardinode);


$cce->bye('SUCCESS');
exit 0;
